candv: Constants & Values
=========================

|pypi_package| |pypi_downloads| |python_versions| |docs| |license|

|unix_build| |coverage_status|


This is a little Python library which provides an easy way for creating complex
constants.

Inspired by `Constants from Twisted`_ and `Django form fields`_.

Please, `read the docs`_ for more information.

.. |unix_build| image:: http://img.shields.io/travis/oblalex/candv.svg?branch=master&style=flat
   :target: https://travis-ci.org/oblalex/candv

.. |coverage_status| image:: http://img.shields.io/coveralls/oblalex/candv.svg?branch=master&style=flat
   :target: https://coveralls.io/r/oblalex/candv?branch=master
   :alt: Test coverage

.. |pypi_package| image:: http://img.shields.io/pypi/v/candv.svg?style=flat
   :target: http://badge.fury.io/py/candv/
   :alt: Version of PyPI package

.. |pypi_downloads| image:: http://img.shields.io/pypi/dm/candv.svg?style=flat
   :target: https://crate.io/packages/candv/
   :alt: Number of downloads of PyPI package

.. |python_versions| image:: https://img.shields.io/badge/Python-2.7,3.3,3.4-brightgreen.svg?style=flat
   :alt: Supported versions of Python

.. |docs| image:: https://readthedocs.org/projects/candv/badge/?version=latest
   :target: `read the docs`_
   :alt: Documentation Status

.. |license| image:: https://img.shields.io/badge/license-LGPLv3-blue.svg?style=flat
   :target: https://github.com/IL2HorusTeam/il2fb-difficulty/blob/master/LICENSE
   :alt: Package license


.. _Constants from Twisted: http://twistedmatrix.com/documents/current/core/howto/constants.html
.. _Django form fields: https://docs.djangoproject.com/en/1.6/ref/forms/fields/
.. _read the docs: http://candv.readthedocs.org/en/latest/
